%define i18ndate 20010626
%define base_version 5.2
%define patchlevel 21
%define rel 1

Name:		bash
Version:	%{base_version}%{?patchlevel:.%{patchlevel}}
Release:	%mkrel %{rel}
Summary:	The GNU Bourne Again shell (bash)
Group:		Shells
License:	GPLv2+
URL:		https://www.gnu.org/software/bash/bash.html
Source0:	https://ftp.gnu.org/gnu/bash/%{name}-%{version}.tar.gz
Source2:	https://ftp.gnu.org/gnu/bash/bash-doc-3.2.tar.bz2
Source3:	dot-bashrc
Source4:	dot-bash_profile
Source5:	dot-bash_logout
Source6:	alias.sh
Source7:	bashrc
Source8:	profile.d-bash

# Mageia/Mandriva patches
Patch1001:	bash-2.02-security.patch
Patch1003:	bash-4.0-profile.patch
Patch1006:	bash-2.04-compat.patch
Patch1020:	bash-strcoll-bug.diff
Patch1024:	bash-3.2-lzma-copmpletion.patch

BuildRequires:	autoconf2.5
BuildRequires:	bison
BuildRequires:	groff
BuildRequires:	pkgconfig(tinfo)
BuildRequires:	texinfo
# explicit file provides
Provides:	/bin/sh
Provides:	/usr/bin/sh
Provides:	/bin/bash
Provides:	/usr/bin/bash

%description
Bash is a GNU project sh-compatible shell or command language
interpreter. Bash (Bourne Again shell) incorporates useful features
from the Korn shell (ksh) and the C shell (csh). Most sh scripts
can be run by bash without modification.

Bash offers several improvements over sh, including command line
editing, unlimited size command history, job control, shell
functions and aliases, indexed arrays of unlimited size and
integer arithmetic in any base from two to 64. Bash is ultimately
intended to conform to the IEEE POSIX P1003.2/ISO 9945.2 Shell and
Tools standard.

%package doc
Summary:	Documentation for the GNU Bourne Again shell (bash)
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
This package provides documentation for GNU Bourne Again shell (bash).

%prep
%setup -q -a 2 -n %{name}-%{version}
mv doc/README .

%patch1001 -p1 -b .security
%patch1003 -p1 -b .profile
%patch1020 -p1 -b .strcoll_bugx
%patch1024 -p1 -b .lzma

%build

export CFLAGS="%{optflags} -Os"
export CXXFLAGS="$CFLAGS"
export DEBUGGER_START_FILE="%{_datadir}/bashdb/bashdb-main.inc"

%configure2_5x \
    --enable-command-timing \
    --disable-rpath \
    --enable-history \
    --enable-job-control \
    --enable-multibyte \
    --enable-readline \
    --without-gnu-malloc \
    --without-bash-malloc \
    --disable-strict-posix-default \
    --enable-select \
    --enable-prompt-string-decoding \
    --enable-process-substitution \
    --enable-alias \
    --enable-bang-history \
    --enable-coprocesses \
    --enable-directory-stack \
    --enable-brace-expansion

make

%install
rm -rf %buildroot
%make_install

# beurk
rm -rf %{buildroot}%{_datadir}/locale/en@boldquot/ %{buildroot}%{_datadir}/locale/en@quot/

#Sucks
chmod +w doc/texinfo.tex
chmod 755 examples/misc/aliasconv.*
chmod 755 examples/misc/cshtobash
chmod 755 %{buildroot}%{_bindir}/bashbug

# Take out irritating ^H's from the documentation
mkdir tmp_doc
for i in `/bin/ls doc/` ; \
	do cat doc/$i > tmp_doc/$i ; \
	cat tmp_doc/$i | perl -p -e 's/.//g' > doc/$i ; \
	rm tmp_doc/$i ; \
	done
rmdir tmp_doc

mkdir -p %{buildroot}/bin
( cd %{buildroot} && mv usr/bin/bash bin/bash )
( cd %{buildroot}/bin && ln -s bash sh )

# make builtins.1 and rbash.1 with bash.1 in place (fix mdv#51379)
(cd doc
mkdir tmp_fix_so
cd tmp_fix_so
cp ../builtins.1 ../rbash.1 .
sed -e '/^.if \\n(zZ=1 .ig zZ/,/^.zZ/d' ../bash.1 > bash.1
soelim builtins.1 > ../builtins.1
sed -e '/^.if \\n(zY=1 .ig zY/,/^.zY/d' ../bash.1 > bash.1
soelim rbash.1    > ../rbash.1
)
rm -rf doc/tmp_fix_so

# make manpages for bash builtins as per suggestion in DOC/README
(cd doc
sed -e '
/^\.SH NAME/, /\\- bash built-in commands, see \\fBbash\\fR(1)$/{
/^\.SH NAME/d
s/^bash, //
s/\\- bash built-in commands, see \\fBbash\\fR(1)$//
s/,//g
b
}
d
' builtins.1 | tr -s ' ' '\n' | grep -v -E '^(printf|export|echo|pwd|test|kill)$' > man.pages
# tr is needed because there are few commands in a row separated with a whilespace
# echo,export,kill,printf,pwd,test -- these files are provided by other packages

install -m 644 builtins.1 %{buildroot}%{_mandir}/man1/builtins.1

install -m 644 rbash.1 %{buildroot}%{_mandir}/man1/rbash.1

for i in `cat man.pages` ; do
# install man-page
  echo .so man1/builtins.1 > %{buildroot}%{_mandir}/man1/$i.1

# now turn man.page into a filelist for the man subpackage
  echo "%{_mandir}/man1/$i.1%{_extension}" >> ../man.pages.filelist
done


mkdir -p %{buildroot}%{_sysconfdir}/skel
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/skel/.bashrc
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/skel/.bash_profile
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/skel/.bash_logout
install -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/profile.d/60alias.sh
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/bashrc
install -m 644 %{SOURCE8} %{buildroot}%{_sysconfdir}/profile.d/95bash-extras.sh

ln -s bash %{buildroot}/bin/rbash

install -m 644 bash.info %{buildroot}%{_infodir}
)

%find_lang %{name}

# merges list
cat man.pages.filelist %{name}.lang > files.list

%files -f files.list
%doc %dir %{_docdir}/%{name}
%{_sysconfdir}/skel/.b*
%{_sysconfdir}/profile.d/60alias.sh
%{_sysconfdir}/profile.d/95bash-extras.sh
%{_sysconfdir}/bashrc
/bin/rbash
/bin/bash
/bin/sh
%{_infodir}/bash.info*
%{_mandir}/man1/bash.1*
%{_mandir}/man1/rbash.1*
%{_mandir}/man1/builtins.1*
%{_mandir}/man1/bashbug.1*
%{_bindir}/bashbug


%files doc
%doc examples
%doc doc/*.ps doc/*.0 doc/*.html doc/article.txt
%{_docdir}/%{name}

%pre
rm -rf %{_sysconfdir}/skel/.b*
rm -rf %{_sysconfdir}/profile.d/60alias.sh
rm -rf %{_sysconfdir}/profile.d/95bash-extras.sh
rm -rf %{_sysconfdir}/bashrc

%changelog
* Fri Nov 10 2023 tex - 5.2.21-1pclos2023
- new version
- swtich to released tarball

* Tue Dec 13 2022 tex - 5.2.15-1pclos2022
- new version
